%global oversion %{version}M10

Name:           woden
Version:        1.0
Release:        0.20.M10%{?dist}
Summary:        Web Service Description Language (WSDL) validating parser
License:        ASL 2.0
URL:            http://ws.apache.org/woden/
Source0:        http://archive.apache.org/dist/ws/woden/%{oversion}/woden-%{oversion}-src.zip
BuildArch:      noarch
  
BuildRequires:  maven-local
BuildRequires:  mvn(commons-logging:commons-logging)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(log4j:log4j:1.2.15)
BuildRequires:  mvn(org.apache.ant:ant)
BuildRequires:  mvn(org.apache:apache:pom:)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.ws.xmlschema:xmlschema-core)
BuildRequires:  mvn(org.codehaus.mojo:exec-maven-plugin)
BuildRequires:  mvn(wsdl4j:wsdl4j)

# For xsltproc command
BuildRequires:  libxslt

%description
The Woden project is a sub-project of the Apache Web Services Project
to develop a Java class library for reading, manipulating, creating
and writing WSDL documents, initially to support WSDL 2.0 but with the
longer term aim of supporting past, present and future versions of WSDL.

%package parent
Summary: Parent pom of %{name} project

%description parent
Parent pom of %{name} project.

%package tool
Summary: Command line tool for converting WSDL documents
# Explicit requires for javapackages-tools since woden-tool script
# uses /usr/share/java-utils/java-functions
Requires:       javapackages-tools

%description tool
Command line tool for converting WSDL documents.

%package ant
Summary: Ant plug-in for converting WSDL documents

%description ant
Ant plug-in for converting WSDL documents.

%package maven-plugin
Summary: Maven plug-in for converting WSDL documents

%description maven-plugin
Maven plug-in for converting WSDL documents.

%package javadoc
Summary: Javadocs for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n woden-%{oversion}

# Using ws-parent doesn't add anything, may as well use apache-parent
%pom_set_parent "org.apache:apache:17"

# org.codehaus.mojo:xslt-maven-plugin is not available so use command line tool instead
%pom_remove_plugin org.codehaus.mojo:xslt-maven-plugin woden-tool
%pom_add_plugin "org.codehaus.mojo:exec-maven-plugin:1.6.0" woden-tool "
  <executions>
    <execution>
      <goals><goal>exec</goal></goals>
      <phase>compile</phase>
    </execution>
  </executions>
  <configuration>
    <executable>xsltproc</executable>
    <arguments>
      <argument>-o</argument>
      <argument>\${project.build.outputDirectory}/wsdl-viewer-modules.xsl</argument>
      <argument>all-in-one.xsl</argument>
      <argument>src/main/xslt/wsdl-viewer-modules.xsl</argument>
    </arguments>
  </configuration>"

# Avoid use of deprecated plexus-maven-plugin
%pom_remove_plugin ":plexus-maven-plugin" woden-converter-maven-plugin

# These module contain only testdata and according to upstream, should not be deployed
%pom_disable_module woden-tests
%pom_disable_module w3c-tests

# Disable unnecessary plugin for RPM builds, Fedora doesn't ship source jars
%pom_remove_plugin :maven-source-plugin

# Don't need to build the dist assembly for RPM builds
%pom_disable_module woden-dist

# Compatibility aliases
%mvn_alias :woden-core :woden-api :woden-impl-commons :woden-impl-dom

%build
%mvn_build -s

# Fix encoding
iconv -f iso8859-1 -t utf-8 LICENSE > LICENSE.utf8
mv LICENSE.utf8 LICENSE

%install
%mvn_install

%jpackage_script "org.apache.woden.tool.converter.Convert" "" "" "woden:XmlSchema:wsdl4j:commons-logging" "woden-tool" true

%files -f .mfiles-woden-core
%doc README RELEASE-NOTE
%license LICENSE NOTICE

%files parent -f .mfiles-woden
%license LICENSE NOTICE

%files tool -f .mfiles-woden-tool
%{_bindir}/woden-tool

%files ant -f .mfiles-woden-ant

%files maven-plugin -f .mfiles-woden-converter-maven-plugin

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE

%changelog
* Sun Feb 03 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-0.20.M10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Aug 31 2018 Severin Gehwolf <sgehwolf@redhat.com> - 1.0-0.19.M10
- Add explicit javapackages-tools requirement for woden-tool script.
  See RHBZ#1600426.

* Sat Jul 14 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-0.18.M10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Mon Apr 16 2018 Mat Booth <mat.booth@redhat.com> - 1.0-0.17.M10
- Update to latest upstream release
- Build missing modules

* Fri Feb 09 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-0.16.M9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-0.15.M9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-0.14.M9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Mon Jun 20 2016 gil cattaneo <puntogil@libero.it> 1.0-0.13.M9
- add missing build requires: maven-plugin-bundle

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.0-0.12.M9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-0.11.M9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Feb 13 2015 gil cattaneo <puntogil@libero.it> 1.0-0.10.M9
- introduce license macro

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-0.9.M9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Mar 28 2014 Michael Simacek <msimacek@redhat.com> - 1.0-0.8.M9
- Use Requires: java-headless rebuild (#1067528)

* Wed Aug 14 2013 Mat Booth <fedora@matbooth.co.uk> - 1.0-0.7.M9
- Update for latest guidelines, rhbz #992879

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-0.6.M9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Feb 22 2013 Andy Grimm <agrimm@gmail.com> - 1.0-0.4.M9
- Add maven-shared to BuildRequires (RHBZ#914574)

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-0.4.M9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Feb 06 2013 Java SIG <java-devel@lists.fedoraproject.org> - 1.0-0.3.M9
- Update for https://fedoraproject.org/wiki/Fedora_19_Maven_Rebuild
- Replace maven BuildRequires with maven-local

* Sun Jul 22 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0-0.2.M9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Mon Feb 20 2012 Andy Grimm <agrimm@gmail.com> - 1.0-0.1.M9
- Initial package
